@@ -9,10 +9,10 @@ from contextlib import contextmanager
 from contextvars import ContextVar
 from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
-from ._common import Action, is_subclass, parser_context
+from ._common import Action, is_not_subclass_type, is_subclass, parser_context
 from ._loaders_dumpers import get_loader_exceptions, load_value
 from ._namespace import Namespace, NSKeyError, split_key, split_key_root
-from ._optionals import _get_config_read_mode
+from ._optionals import _get_config_read_mode, ruamel_support
 from ._type_checking import ActionsContainer, ArgumentParser
 from ._util import (
     Path,
@@ -20,7 +20,6 @@ from ._util import (
     change_to_path_dir,
     default_config_option_help,
     get_import_path,
-    get_typehint_origin,
     import_object,
     indent_text,
     iter_to_set_str,
@@ -29,8 +28,9 @@ from ._util import (
 
 __all__ = [
     "ActionConfigFile",
-    "ActionYesNo",
+    "ActionFail",
     "ActionParser",
+    "ActionYesNo",
 ]
 
 
@@ -65,7 +65,7 @@ def _find_action_and_subcommand(
     fallback_action = None
     for action in actions:
         if action.dest == dest or f"--{dest}" in action.option_strings:
-            if isinstance(action, _ActionConfigLoad):
+            if isinstance(action, (_ActionConfigLoad, ActionFail)):
                 fallback_action = action
             else:
                 return action, None
@@ -251,13 +251,16 @@ class _ActionPrintConfig(Action):
             help=(
                 "Print the configuration after applying all other arguments and exit. The optional "
                 "flags customizes the output and are one or more keywords separated by comma. The "
-                "supported flags are: comments, skip_default, skip_null."
-            ),
+                "supported flags are:%s skip_default, skip_null."
+            )
+            % (" comments," if ruamel_support else ""),
         )
 
     def __call__(self, parser, namespace, value, option_string=None):
         kwargs = {"subparser": parser, "key": None, "skip_none": False, "skip_validation": False}
-        valid_flags = {"": None, "comments": "yaml_comments", "skip_default": "skip_default", "skip_null": "skip_none"}
+        valid_flags = {"": None, "skip_default": "skip_default", "skip_null": "skip_none"}
+        if ruamel_support:
+            valid_flags["comments"] = "yaml_comments"
         if value is not None:
             flags = value[0].split(",")
             invalid_flags = [f for f in flags if f not in valid_flags]
@@ -343,42 +346,42 @@ class _ActionConfigLoad(Action):
 class _ActionHelpClassPath(Action):
     sub_add_kwargs: Dict[str, Any] = {}
 
+    @classmethod
+    def get_help_types(cls, typehint) -> Optional[tuple]:
+        from ._typehints import get_subclass_or_closed_types
+
+        return get_subclass_or_closed_types(typehint=typehint, also_lists=True, callable_return=True)
+
     def __init__(self, typehint=None, **kwargs):
         if typehint is not None:
             self._typehint = typehint
         else:
-            self._typehint = kwargs.pop("_typehint")
             self.update_init_kwargs(kwargs)
             super().__init__(**kwargs)
 
     def update_init_kwargs(self, kwargs):
-        from ._typehints import (
-            get_optional_arg,
-            get_subclass_names,
-            get_subclass_types,
-            get_unaliased_type,
-            is_protocol,
-        )
+        from ._typehints import is_protocol
 
-        typehint = get_unaliased_type(get_optional_arg(self._typehint))
-        if get_typehint_origin(typehint) is not Union:
-            assert "nargs" not in kwargs
-            kwargs["nargs"] = "?"
-        self._basename = iter_to_set_str(get_subclass_names(self._typehint, callable_return=True))
-        self._baseclasses = get_subclass_types(typehint, callable_return=True)
-        assert self._baseclasses
+        self._typehint = kwargs.pop("_typehint")
+        self._help_types = self.get_help_types(self._typehint)
+        assert self._help_types and all(isinstance(b, type) for b in self._help_types)
+        self._not_subclass = len(self._help_types) == 1 and is_not_subclass_type(self._help_types[0])
+        self._basename = iter_to_set_str(t.__name__ for t in self._help_types)
 
-        self._kind = "subclass of"
-        if any(is_protocol(b) for b in self._baseclasses):
-            self._kind = "subclass or implementer of protocol"
+        if len(self._help_types) == 1:
+            kwargs["nargs"] = 0 if self._not_subclass else "?"
 
-        kwargs.update(
-            {
-                "metavar": "CLASS_PATH_OR_NAME",
-                "default": SUPPRESS,
-                "help": f"Show the help for the given {self._kind} {self._basename} and exit.",
-            }
-        )
+        if self._not_subclass:
+            msg = ""
+        else:
+            kwargs["metavar"] = "CLASS_PATH_OR_NAME"
+            self._kind = "subclass of"
+            if any(is_protocol(b) for b in self._help_types):
+                self._kind = "subclass or implementer of protocol"
+            msg = f"the given {self._kind} "
+
+        kwargs["default"] = SUPPRESS
+        kwargs["help"] = f"Show the help for {msg}{self._basename} and exit."
 
     def __call__(self, *args, **kwargs):
         if len(args) == 0:
@@ -388,28 +391,28 @@ class _ActionHelpClassPath(Action):
 
     def print_help(self, call_args):
         from ._typehints import (
-            ActionTypeHint,
-            get_optional_arg,
-            get_unaliased_type,
+            adapt_partial_callable_class,
             implements_protocol,
             resolve_class_path_by_name,
         )
 
         parser, _, value, option_string = call_args
         try:
-            typehint = get_unaliased_type(get_optional_arg(self._typehint))
-            if self.nargs == "?" and value is None:
-                val_class = typehint
+            if self.nargs == 0 or (self.nargs == "?" and value is None):
+                val_class = self._help_types[0]
             else:
-                val_class = import_object(resolve_class_path_by_name(typehint, value))
+                val_class = import_object(resolve_class_path_by_name(self._help_types, value))
         except Exception as ex:
             raise TypeError(f"{option_string}: {ex}") from ex
-        if not any(is_subclass(val_class, b) or implements_protocol(val_class, b) for b in self._baseclasses):
+
+        if not any(is_subclass(val_class, b) or implements_protocol(val_class, b) for b in self._help_types):
             raise TypeError(f'{option_string}: Class "{value}" is not a {self._kind} {self._basename}')
         dest = re.sub("\\.help$", "", self.dest)
         subparser = type(parser)(description=f"Help for {option_string}={get_import_path(val_class)}")
-        if ActionTypeHint.is_callable_typehint(typehint) and hasattr(typehint, "__args__"):
-            self.sub_add_kwargs["skip"] = {max(0, len(typehint.__args__) - 1)}
+        val = Namespace(class_path=get_import_path(val_class))
+        _, partial_skip_args = adapt_partial_callable_class(self._typehint, val)
+        if partial_skip_args:
+            self.sub_add_kwargs["skip"] = partial_skip_args
         subparser.add_class_arguments(val_class, dest, **self.sub_add_kwargs)
         subparser._inner_parser = True
         remove_actions(subparser, (_HelpAction, _ActionPrintConfig, _ActionConfigLoad))
@@ -432,6 +435,34 @@ class _ActionHelpClassPath(Action):
         return args[num + 1 :]
 
 
+class ActionFail(Action):
+    """Action that always fails parsing with a given error."""
+
+    def __init__(self, message: str = "option unavailable", **kwargs):
+        """Initializer for ActionFail instance.
+
+        Args:
+            message: Text for the error to show. Use `%(option)s`/`%(value)s` to include the option and/or value.
+        """
+        if len(kwargs) == 0:
+            self._message = message
+        else:
+            self._message = kwargs.pop("_message")
+            kwargs["default"] = SUPPRESS
+            kwargs["required"] = False
+            if kwargs["option_strings"] == []:
+                kwargs["nargs"] = "?"
+            super().__init__(**kwargs)
+
+    def __call__(self, *args, **kwargs):
+        """Always fails with given message."""
+        if len(args) == 0:
+            kwargs["_message"] = self._message
+            return ActionFail(**kwargs)
+        parser, _, value, option = args
+        parser.error(self._message % {"value": value, "option": option})
+
+
 class ActionYesNo(Action):
     """Paired options --[yes_prefix]opt, --[no_prefix]opt to set True or False respectively."""
 
