@@ -43,7 +43,7 @@ from ._common import (
     class_instantiators,
     debug_mode_active,
     get_optionals_as_positionals_actions,
-    is_dataclass_like,
+    is_not_subclass_type,
     lenient_check,
     parser_context,
     supports_optionals_as_positionals,
@@ -64,7 +64,6 @@ from ._loaders_dumpers import (
     get_loader_exceptions,
     load_value,
     loaders,
-    set_omegaconf_loader,
 )
 from ._namespace import (
     Namespace,
@@ -82,6 +81,7 @@ from ._optionals import (
     fsspec_support,
     import_fsspec,
     import_jsonnet,
+    omegaconf_apply,
     pyyaml_available,
 )
 from ._parameter_resolvers import UnknownDefault
@@ -131,7 +131,7 @@ class ActionsContainer(SignatureArguments, argparse._ActionsContainer):
                 return ActionParser._move_parser_actions(parser, args, kwargs)
             ActionConfigFile._ensure_single_config_argument(self, kwargs["action"])
         if "type" in kwargs:
-            if is_dataclass_like(kwargs["type"]):
+            if is_not_subclass_type(kwargs["type"]):
                 nested_key = args[0].lstrip("-")
                 self.add_class_arguments(kwargs.pop("type"), nested_key, **kwargs)
                 return _find_action(parser, nested_key)
@@ -151,7 +151,7 @@ class ActionsContainer(SignatureArguments, argparse._ActionsContainer):
         ActionJsonnet._check_ext_vars_action(parser, action)
         if is_meta_key(action.dest):
             raise ValueError(f'Argument with destination name "{action.dest}" not allowed.')
-        if action.option_strings == [] and "default" in kwargs:
+        if action.option_strings == [] and "default" in kwargs and kwargs["default"] is not argparse.SUPPRESS:
             raise ValueError("Positional arguments not allowed to have a default value.")
         validate_default(self, action)
         if action.help is None:
@@ -301,9 +301,11 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
         namespace = argcomplete_namespace(caller, self, namespace)
 
         try:
-            with patch_namespace(), parser_context(
-                parent_parser=self, lenient_check=True
-            ), ActionTypeHint.subclass_arg_context(self):
+            with (
+                patch_namespace(),
+                parser_context(parent_parser=self, lenient_check=True),
+                ActionTypeHint.subclass_arg_context(self),
+            ):
                 kwargs = {}
                 if _parse_known_has_intermixed:
                     kwargs["intermixed"] = False
@@ -376,9 +378,12 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
             with parser_context(lenient_check=True):
                 ActionTypeHint.add_sub_defaults(self, cfg)
 
-        _ActionPrintConfig.print_config_if_requested(self, cfg)
-
         with parser_context(parent_parser=self):
+            if not lenient_check.get() and self.parser_mode == "omegaconf+":
+                cfg = omegaconf_apply(self, cfg)
+
+            _ActionPrintConfig.print_config_if_requested(self, cfg)
+
             try:
                 ActionLink.apply_parsing_links(self, cfg)
             except Exception as ex:
@@ -924,25 +929,36 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
 
             ActionLink.strip_link_target_keys(self, cfg)
 
+            def is_path_action(key):
+                action = _find_action(self, key)
+                return isinstance(action, (ActionJsonSchema, ActionJsonnet, ActionTypeHint, _ActionConfigLoad))
+
+            def save_path(val):
+                val_path = Path(os.path.basename(val["__path__"].absolute), mode="fc")
+                check_overwrite(val_path)
+                val_out = strip_meta(val)
+                if isinstance(val, Namespace):
+                    val_out = val_out.as_dict()
+                if "__orig__" in val:
+                    val_str = val["__orig__"]
+                else:
+                    is_json = str(val_path).lower().endswith(".json")
+                    val_str = dump_using_format(self, val_out, "json_indented" if is_json else format)
+                with open(val_path.absolute, "w") as f:
+                    f.write(val_str)
+                return os.path.basename(val_path)
+
             def save_paths(cfg):
                 for key in cfg.get_sorted_keys():
                     val = cfg[key]
                     if isinstance(val, (Namespace, dict)) and "__path__" in val:
-                        action = _find_action(self, key)
-                        if isinstance(action, (ActionJsonSchema, ActionJsonnet, ActionTypeHint, _ActionConfigLoad)):
-                            val_path = Path(os.path.basename(val["__path__"].absolute), mode="fc")
-                            check_overwrite(val_path)
-                            val_out = strip_meta(val)
-                            if isinstance(val, Namespace):
-                                val_out = val_out.as_dict()
-                            if "__orig__" in val:
-                                val_str = val["__orig__"]
-                            else:
-                                is_json = str(val_path).lower().endswith(".json")
-                                val_str = dump_using_format(self, val_out, "json_indented" if is_json else format)
-                            with open(val_path.absolute, "w") as f:
-                                f.write(val_str)
-                            cfg[key] = os.path.basename(val_path.absolute)
+                        if is_path_action(key):
+                            cfg[key] = save_path(val)
+                    elif isinstance(val, list):
+                        if is_path_action(key):
+                            for num, item in enumerate(val):
+                                if isinstance(item, (Namespace, dict)) and "__path__" in item:
+                                    val[num] = save_path(item)
                     elif isinstance(val, Path) and key in self.save_path_content and "r" in val.mode:
                         val_path = Path(os.path.basename(val.absolute), mode="fc")
                         check_overwrite(val_path)
@@ -1230,9 +1246,7 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
         """
         components: List[Union[ActionTypeHint, _ActionConfigLoad, ArgumentGroup]] = []
         for action in filter_default_actions(self._actions):
-            if isinstance(action, ActionTypeHint) or (
-                isinstance(action, _ActionConfigLoad) and is_dataclass_like(action.basetype)
-            ):
+            if isinstance(action, ActionTypeHint):
                 components.append(action)
 
         if instantiate_groups:
@@ -1352,9 +1366,9 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
             cfg_branch = cfg
             cfg = Namespace()
             cfg[parent_key] = cfg_branch
-            keys = [parent_key + "." + k for k in cfg_branch.__dict__]
+            keys = [parent_key + "." + k for k in cfg_branch.keys(branches=True, nested=False)]
         else:
-            keys = list(cfg.__dict__)
+            keys = list(cfg.keys(branches=True, nested=False))
 
         if prev_cfg:
             prev_cfg = prev_cfg.clone()
@@ -1381,7 +1395,7 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
                 if isinstance(value, dict):
                     value = Namespace(value)
                 if isinstance(value, Namespace):
-                    new_keys = value.__dict__.keys()
+                    new_keys = value.keys(branches=True, nested=False)
                     keys += [key + "." + k for k in new_keys if key + "." + k not in keys]
                 cfg[key] = value
                 continue
@@ -1399,6 +1413,13 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
             if isinstance(action, _ActionConfigLoad):
                 config_keys.add(action_dest)
                 keys.append(action_dest)
+            elif isinstance(action, ActionConfigFile):
+                if isinstance(value, str):
+                    cfg.pop(action_dest)
+                    preserve = Namespace({k: cfg[k] for k in keys[num:]})
+                    ActionConfigFile.apply_config(self, cfg, action_dest, value)
+                    cfg.update(preserve)
+                    continue
             elif getattr(action, "jsonnet_ext_vars", False):
                 prev_cfg[action_dest] = value
             cfg[action_dest] = value
@@ -1448,7 +1469,7 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
                 value = action.check_type(value, self)
         elif hasattr(action, "_check_type"):
             with parser_context(parent_parser=self):
-                value = action._check_type_(value, cfg=cfg, append=append)  # type: ignore[attr-defined]
+                value = action._check_type_(value, cfg=cfg, append=append, mode=self.parser_mode)  # type: ignore[attr-defined]
         elif action.type is not None:
             try:
                 if action.nargs in {None, "?"} or action.nargs == 0:
@@ -1591,10 +1612,9 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
 
     @parser_mode.setter
     def parser_mode(self, parser_mode: str):
-        if parser_mode == "omegaconf":
-            set_omegaconf_loader()
-        if parser_mode not in loaders:
-            raise ValueError(f"The only accepted values for parser_mode are {set(loaders)}.")
+        accepted = set(loaders).union({"omegaconf", "omegaconf+"})
+        if parser_mode not in accepted:
+            raise ValueError(f"The only accepted values for parser_mode are {accepted}.")
         if parser_mode == "jsonnet":
             import_jsonnet("parser_mode=jsonnet")
         self._parser_mode = parser_mode
@@ -1623,8 +1643,7 @@ class ArgumentParser(ParserDeprecations, ActionsContainer, ArgumentLinking, Logg
         self._dump_header = dump_header
 
 
-from ._deprecated import instantiate_subclasses_patch, parse_as_dict_patch  # noqa: E402
+from ._deprecated import parse_as_dict_patch  # noqa: E402
 
-instantiate_subclasses_patch()
 if "SPHINX_BUILD" not in os.environ:
     parse_as_dict_patch()
