@@ -2,11 +2,19 @@
 
 import inspect
 import re
+from argparse import HelpFormatter
 from contextlib import suppress
 from typing import Any, Callable, Dict, Optional, Set, Tuple, Type
 
 from ._common import load_value_mode, parent_parser
-from ._optionals import import_jsonnet, import_toml_dumps, import_toml_loads, omegaconf_support, pyyaml_available
+from ._optionals import (
+    import_jsonnet,
+    import_toml_dumps,
+    import_toml_loads,
+    omegaconf_support,
+    pyyaml_available,
+    ruamel_support,
+)
 from ._type_checking import ArgumentParser
 
 __all__ = [
@@ -188,10 +196,12 @@ def load_value(value: str, simple_types: bool = False, **kwargs):
     loaded_value = load_basic(value)
 
     mode = get_load_value_mode()
-    if loaded_value is not_loaded and not loader_json_superset[mode]:
+    if loaded_value is not_loaded and not loader_json_superset.get(mode, True):
         loaded_value = load_list_or_dict(value)
 
     if loaded_value is not_loaded:
+        if mode not in loaders and mode in {"omegaconf", "omegaconf+"}:
+            set_omegaconf_loader(mode)
         loader = loaders[mode]
         load_kwargs = {}
         if kwargs and mode in loader_params:
@@ -225,7 +235,8 @@ def yaml_dump(data):
 
 def yaml_comments_dump(data, parser):
     dump = dumpers["yaml"](data)
-    formatter = parser.formatter_class(parser.prog)
+    formatter_class = create_help_formatter_with_comments(parser.formatter_class)
+    formatter = formatter_class(parser.prog)
     return formatter.add_yaml_comments(dump)
 
 
@@ -248,13 +259,14 @@ def toml_dump(data):
 
 dumpers: Dict[str, Callable] = {
     "yaml": yaml_dump,
-    "yaml_comments": yaml_comments_dump,
     "json": json_compact_dump,
     "json_compact": json_compact_dump,
     "json_indented": json_indented_dump,
     "toml": toml_dump,
     "jsonnet": json_indented_dump,
 }
+if ruamel_support:
+    dumpers["yaml_comments"] = yaml_comments_dump
 
 comment_prefix: Dict[str, str] = {
     "yaml": "# ",
@@ -325,11 +337,35 @@ def set_dumper(format_name: str, dumper_fn: Callable[[Any], str]):
     dumpers[format_name] = dumper_fn
 
 
-def set_omegaconf_loader():
-    if omegaconf_support and "omegaconf" not in loaders:
+def set_omegaconf_loader(mode="omegaconf"):
+    if omegaconf_support and mode not in loaders:
         from ._optionals import get_omegaconf_loader
 
-        set_loader("omegaconf", get_omegaconf_loader(), get_loader_exceptions("yaml"))
+        loader = get_omegaconf_loader(mode)
+        set_loader(mode, loader, get_loader_exceptions("yaml"))
 
 
 set_loader("jsonnet", jsonnet_load, get_loader_exceptions("jsonnet"))
+
+
+def create_help_formatter_with_comments(formatter_class: Type[HelpFormatter]) -> Type[HelpFormatter]:
+    """Creates a dynamic class that combines a formatter with YAML comment functionality.
+
+    Args:
+        formatter_class: The base formatter class to extend.
+
+    Returns:
+        A new class that inherits from both the formatter and YAMLCommentFormatter.
+    """
+    from ._formatters import YAMLCommentFormatter
+
+    class DynamicHelpFormatter(formatter_class):  # type: ignore[valid-type,misc]
+        def __init__(self, *args, **kwargs):
+            super().__init__(*args, **kwargs)
+            self._yaml_formatter = YAMLCommentFormatter(self)
+
+        def add_yaml_comments(self, cfg: str) -> str:
+            """Adds help text as yaml comments."""
+            return self._yaml_formatter.add_yaml_comments(cfg)
+
+    return DynamicHelpFormatter
