@@ -12,12 +12,12 @@ from ._common import (
     get_class_instantiator,
     get_generic_origin,
     get_unaliased_type,
-    is_dataclass_like,
     is_final_class,
+    is_not_subclass_type,
     is_subclass,
 )
 from ._namespace import Namespace
-from ._optionals import attrs_support, get_doc_short_description, is_pydantic_model, pydantic_support
+from ._optionals import attrs_support, get_doc_short_description, is_attrs_class, is_pydantic_model
 from ._parameter_resolvers import ParamData, get_parameter_origins, get_signature_parameters
 from ._typehints import (
     ActionTypeHint,
@@ -26,8 +26,9 @@ from ._typehints import (
     get_subclass_names,
     is_optional,
     not_required_types,
+    sequence_origin_types,
 )
-from ._util import NoneType, get_private_kwargs, get_typehint_origin, iter_to_set_str
+from ._util import NoneType, get_import_path, get_private_kwargs, get_typehint_origin, iter_to_set_str
 from .typing import register_pydantic_type
 
 __all__ = [
@@ -86,7 +87,7 @@ class SignatureArguments(LoggerProperty):
             or (isinstance(default, LazyInitBaseClass) and isinstance(default, unaliased_class_type))
             or (
                 not is_final_class(default.__class__)
-                and is_dataclass_like(default.__class__)
+                and is_not_subclass_type(default.__class__)
                 and isinstance(default, unaliased_class_type)
             )
         ):
@@ -120,14 +121,12 @@ class SignatureArguments(LoggerProperty):
             defaults = default
             if isinstance(default, LazyInitBaseClass):
                 defaults = default.lazy_get_init_args().as_dict()
-            elif is_dataclass_like(default.__class__):
-                defaults = dataclass_to_dict(default)
+            elif is_convertible_to_dict(default.__class__):
+                defaults = convert_to_dict(default)
                 args = {k[len(prefix) :] for k in added_args}
                 skip_not_added = [k for k in defaults if k not in args]
                 if skip_not_added:
                     skip.update(skip_not_added)  # skip init=False
-            elif isinstance(default, Namespace):
-                defaults = default.as_dict()
             if defaults:
                 defaults = {prefix + k: v for k, v in defaults.items() if k not in skip}
                 self.set_defaults(**defaults)  # type: ignore[attr-defined]
@@ -267,7 +266,7 @@ class SignatureArguments(LoggerProperty):
         """
         params = get_signature_parameters(function_or_class, method_name, logger=self.logger)
 
-        skip_positionals = [s for s in (skip or []) if isinstance(s, int)]
+        skip_positionals = [s for s in (skip or []) if isinstance(s, int) and s != 0]
         if skip_positionals:
             if len(skip_positionals) > 1 or any(p <= 0 for p in skip_positionals):
                 raise ValueError(f"Unexpected number of positionals to skip: {skip_positionals}")
@@ -344,7 +343,22 @@ class SignatureArguments(LoggerProperty):
                     default = None
                 elif get_typehint_origin(annotation) in not_required_types:
                     default = SUPPRESS
-        is_required = default == inspect_empty
+        # Determine argument characteristics based on parameter kind and default value
+        if kind == kinds.POSITIONAL_ONLY:
+            is_required = True  # Always required
+            is_non_positional = False  # Can be positional
+        elif kind == kinds.POSITIONAL_OR_KEYWORD:
+            is_required = default == inspect_empty  # Required if no default
+            is_non_positional = False  # Can be positional
+        elif kind == kinds.KEYWORD_ONLY:
+            is_required = default == inspect_empty  # Required if no default
+            is_non_positional = True  # Must use --flag style
+        elif kind is None:
+            # programmatically created parameters without kind
+            is_required = default == inspect_empty  # Required if no default
+            is_non_positional = False  # Can be positional (preserve old behavior)
+        else:
+            raise RuntimeError(f"The code should never reach here: kind={kind}")  # pragma: no cover
         src = get_parameter_origins(param.component, param.parent)
         skip_message = f'Skipping parameter "{name}" from "{src}" because of: '
         if not fail_untyped and annotation == inspect_empty:
@@ -356,7 +370,7 @@ class SignatureArguments(LoggerProperty):
             default = None
             is_required = False
             is_required_link_target = True
-        if kind in {kinds.VAR_POSITIONAL, kinds.VAR_KEYWORD} or (not is_required and name[0] == "_"):
+        if not is_required and name[0] == "_":
             return
         elif skip and name in skip:
             self.logger.debug(skip_message + "Parameter requested to be skipped.")
@@ -371,12 +385,12 @@ class SignatureArguments(LoggerProperty):
             kwargs["default"] = default
             if default is None and not is_optional(annotation, object) and not is_required_link_target:
                 annotation = Optional[annotation]
-        elif not as_positional:
+        elif not as_positional or is_non_positional:
             kwargs["required"] = True
         is_subclass_typehint = False
-        is_dataclass_like_typehint = is_dataclass_like(annotation)
+        is_not_subclass_typehint = is_not_subclass_type(annotation)
         dest = (nested_key + "." if nested_key else "") + name
-        args = [dest if is_required and as_positional else "--" + dest]
+        args = [dest if is_required and as_positional and not is_non_positional else "--" + dest]
         if param.origin:
             parser = container
             if not isinstance(container, ArgumentParser):
@@ -392,7 +406,7 @@ class SignatureArguments(LoggerProperty):
         if (
             annotation in {str, int, float, bool}
             or is_subclass(annotation, (str, int, float))
-            or is_dataclass_like_typehint
+            or is_not_subclass_typehint
         ):
             kwargs["type"] = annotation
             register_pydantic_type(annotation)
@@ -426,7 +440,7 @@ class SignatureArguments(LoggerProperty):
                 "sub_configs": sub_configs,
                 "instantiate": instantiate,
             }
-            if is_dataclass_like_typehint:
+            if is_not_subclass_typehint:
                 kwargs.update(sub_add_kwargs)
             with ActionTypeHint.allow_default_instance_context():
                 action = container.add_argument(*args, **kwargs)
@@ -477,8 +491,6 @@ class SignatureArguments(LoggerProperty):
         Raises:
             ValueError: When given an invalid base class.
         """
-        if is_dataclass_like(baseclass):
-            raise ValueError("Not allowed for dataclass-like classes.")
         if type(baseclass) is not tuple:
             baseclass = (baseclass,)  # type: ignore[assignment]
         if not baseclass or not all(ActionTypeHint.is_subclass_typehint(c, also_lists=True) for c in baseclass):
@@ -575,19 +587,33 @@ def is_factory_class(value):
     return value.__class__ == dataclasses._HAS_DEFAULT_FACTORY_CLASS
 
 
-def dataclass_to_dict(value) -> dict:
-    if pydantic_support:
-        pydantic_model = is_pydantic_model(type(value))
-        if pydantic_model:
-            return value.dict() if pydantic_model == 1 else value.model_dump()
+def is_convertible_to_dict(value):
+    return dataclasses.is_dataclass(value) or is_attrs_class(value) or is_pydantic_model(value)
 
+
+def convert_to_dict(value) -> dict:
     if attrs_support:
         import attrs
 
-        is_attrs_dataclass = attrs.has(type(value))
-        if is_attrs_dataclass:
+        if attrs.has(type(value)):
             return attrs.asdict(value)
-    return dataclasses.asdict(value)
+
+    value_type = type(value)
+    init_args = {}
+    for name, attr in vars(value).items():
+        attr_type = type(attr)
+        if is_convertible_to_dict(attr_type):
+            attr = convert_to_dict(attr)
+        elif attr_type in sequence_origin_types:
+            attr = attr.copy()
+            for num, item in enumerate(attr):
+                if is_convertible_to_dict(type(item)):
+                    attr[num] = convert_to_dict(item)
+        init_args[name] = attr
+
+    if is_not_subclass_type(value_type):
+        return init_args
+    return {"class_path": get_import_path(value_type), "init_args": init_args}
 
 
 def compose_dataclasses(*args):
