@@ -39,6 +39,7 @@ from typing import (
 from ._actions import (
     Action,
     ActionConfigFile,
+    ActionFail,
     _ActionHelpClassPath,
     _ActionPrintConfig,
     _find_action,
@@ -51,8 +52,11 @@ from ._actions import (
 from ._common import (
     get_class_instantiator,
     get_unaliased_type,
-    is_dataclass_like,
+    is_generic_class,
+    is_instance,
+    is_not_subclass_type,
     is_subclass,
+    lenient_check,
     nested_links,
     parent_parser,
     parser_context,
@@ -257,13 +261,13 @@ class ActionTypeHint(Action):
             self.default = self.normalize_default(self.default)
 
     def normalize_default(self, default):
+        from ._signatures import convert_to_dict, is_convertible_to_dict
+
         is_subclass_type = self.is_subclass_typehint(self._typehint, all_subtypes=False)
         if isinstance(default, LazyInitBaseClass):
-            default = default.lazy_get_init_data()
-        elif is_dataclass_like(default.__class__):
-            from ._signatures import dataclass_to_dict
-
-            default = dataclass_to_dict(default)
+            default = default.lazy_get_init_data().as_dict()
+        elif is_convertible_to_dict(default.__class__):
+            default = convert_to_dict(default)
         elif is_subclass_type and isinstance(default, dict) and "class_path" in default:
             default = subclass_spec_as_namespace(default)
             default.class_path = normalize_import_path(default.class_path, self._typehint)
@@ -271,14 +275,14 @@ class ActionTypeHint(Action):
             default = default.name
         elif is_callable_type(self._typehint) and callable(default) and not inspect.isclass(default):
             default = get_import_path(default)
+        elif ActionTypeHint.is_return_subclass_typehint(self._typehint) and inspect.isclass(default):
+            default = {"class_path": get_import_path(default)}
         elif is_subclass_type and not allow_default_instance.get():
             from ._parameter_resolvers import UnknownDefault
 
             default_type = type(default)
             if not is_subclass(default_type, UnknownDefault) and self.is_subclass_typehint(default_type):
                 raise ValueError("Subclass types require as default either a dict with class_path or a lazy instance.")
-        elif ActionTypeHint.is_return_subclass_typehint(self._typehint) and inspect.isclass(default):
-            default = {"class_path": get_import_path(default)}
         return default
 
     @staticmethod
@@ -288,9 +292,7 @@ class ActionTypeHint(Action):
         typehint = kwargs.pop("type")
         if args[0].startswith("--") and ActionTypeHint.supports_append(typehint):
             args = tuple(list(args) + [args[0] + "+"])
-        if ActionTypeHint.is_subclass_typehint(
-            typehint, all_subtypes=False
-        ) or ActionTypeHint.is_return_subclass_typehint(typehint):
+        if _ActionHelpClassPath.get_help_types(typehint):
             help_option = f"--{args[0]}.help" if args[0][0] != "-" else f"{args[0]}.help"
             help_action = container.add_argument(help_option, action=_ActionHelpClassPath(typehint=typehint))
             if sub_add_kwargs:
@@ -311,7 +313,7 @@ class ActionTypeHint(Action):
             or get_typehint_origin(typehint) in root_types
             or get_registered_type(typehint) is not None
             or is_subclass(typehint, Enum)
-            or is_dataclass_like(typehint)
+            or is_not_subclass_type(typehint)
             or ActionTypeHint.is_subclass_typehint(typehint)
         )
         if full and supported:
@@ -346,13 +348,13 @@ class ActionTypeHint(Action):
             test = all if all_subtypes else any
             k = {"also_lists": also_lists}
             return test(ActionTypeHint.is_subclass_typehint(s, **k) for s in subtypes)
-        return is_single_subclass_typehint(typehint, typehint_origin)
+        return is_single_subclass_type(typehint, typehint_origin)
 
     @staticmethod
     def is_return_subclass_typehint(typehint):
         typehint = get_unaliased_type(get_optional_arg(get_unaliased_type(typehint)))
         typehint_origin = get_typehint_origin(typehint)
-        if typehint_origin in callable_origin_types:
+        if typehint_origin in callable_origin_types or is_instance_factory_protocol(typehint):
             return_type = get_callable_return_type(typehint)
             if ActionTypeHint.is_subclass_typehint(return_type):
                 return True
@@ -405,7 +407,7 @@ class ActionTypeHint(Action):
                 action = _find_parent_action(parser, arg_base[2:])
 
         typehint = typehint_from_action(action)
-        if typehint:
+        if typehint or isinstance(action, ActionFail):
             if parse_optional_num_return == 4:
                 return action, arg_base, sep, explicit_arg
             elif parse_optional_num_return == 1:
@@ -473,7 +475,7 @@ class ActionTypeHint(Action):
             )
 
         with ActionTypeHint.sub_defaults_context(), parent_parsers_context(None, None):
-            parser._apply_actions(cfg, skip_fn=skip_sub_defaults_apply)
+            parser._apply_actions(cfg, skip_fn=skip_sub_defaults_apply, prev_cfg=cfg.clone())
 
     @staticmethod
     def supports_append(action):
@@ -523,7 +525,7 @@ class ActionTypeHint(Action):
             if "nargs" in kwargs and kwargs["nargs"] == 0:
                 raise ValueError("ActionTypeHint does not allow nargs=0.")
             return ActionTypeHint(**kwargs)
-        cfg, val, opt_str = args[1:]
+        parser, cfg, val, opt_str = args
         if not (self.nargs == "?" and val is None):
             if isinstance(opt_str, str) and opt_str.startswith(f"--{self.dest}."):
                 if opt_str.startswith(f"--{self.dest}.init_args."):
@@ -532,7 +534,7 @@ class ActionTypeHint(Action):
                     sub_opt = opt_str[len(f"--{self.dest}.") :]
                 val = NestedArg(key=sub_opt, val=val)
             append = opt_str == f"--{self.dest}+"
-            val = self._check_type_(val, append=append, cfg=cfg)
+            val = self._check_type_(val, append=append, cfg=cfg, mode=parser.parser_mode)
             if is_subclass_spec(val):
                 prev_val = cfg.get(self.dest)
                 if is_subclass_spec(prev_val) and "init_args" in prev_val:
@@ -544,7 +546,7 @@ class ActionTypeHint(Action):
         cfg.update(val, self.dest)
         return None
 
-    def _check_type(self, value, append=False, cfg=None):
+    def _check_type(self, value, append=False, cfg=None, mode=None):
         islist = _is_action_value_list(self)
         if not islist:
             value = [value]
@@ -583,7 +585,14 @@ class ActionTypeHint(Action):
                                 val = adapt_typehints(orig_val, self._typehint, default=self.default, **kwargs)
                             ex = None
                     except ValueError:
-                        if self._enable_path and config_path is None and isinstance(orig_val, str):
+                        if (
+                            lenient_check.get()
+                            and mode == "omegaconf+"
+                            and isinstance(orig_val, str)
+                            and "${" in orig_val
+                        ):
+                            ex = None
+                        elif self._enable_path and config_path is None and isinstance(orig_val, str):
                             msg = f"\n- Expected a config path but {orig_val} either not accessible or invalid\n- "
                             raise type(ex)(msg + str(ex)) from ex
                     if ex:
@@ -626,15 +635,16 @@ class ActionTypeHint(Action):
         return value if islist else value[0]
 
     @staticmethod
-    def get_class_parser(val_class, sub_add_kwargs=None, skip_args=0):
+    def get_class_parser(val_class, sub_add_kwargs=None, skip_args=None):
         if isinstance(val_class, str):
             val_class = import_object(val_class)
         kwargs = dict(sub_add_kwargs) if sub_add_kwargs else {}
         if skip_args:
-            kwargs.setdefault("skip", set()).add(skip_args)
-        if is_subclass_spec(kwargs.get("default")):
-            kwargs["default"] = kwargs["default"].get("init_args")
+            kwargs.setdefault("skip", set()).update(skip_args)
         parser = parent_parser.get()
+        from ._core import ArgumentParser
+
+        assert isinstance(parser, ArgumentParser)
         parser = type(parser)(exit_on_error=False, logger=parser.logger, parser_mode=parser.parser_mode)
         remove_actions(parser, (ActionConfigFile, _ActionPrintConfig))
         if inspect.isclass(val_class) or inspect.isclass(get_typehint_origin(val_class)):
@@ -658,11 +668,10 @@ class ActionTypeHint(Action):
     def extra_help(self):
         extra = ""
         typehint = get_optional_arg(self._typehint)
-        if self.is_subclass_typehint(typehint, all_subtypes=False) or get_typehint_origin(
-            typehint
-        ) in callable_origin_types.union({Type, type}):
-            if self.is_callable_typehint(typehint) and getattr(typehint, "__args__", None):
-                typehint = get_callable_return_type(get_optional_arg(typehint))
+        typehint = get_callable_return_type(typehint) or typehint
+        if get_typehint_origin(typehint) is type:
+            typehint = typehint.__args__[0]
+        if self.is_subclass_typehint(typehint, all_subtypes=False):
             class_paths = get_all_subclass_paths(typehint)
             if class_paths:
                 extra = ", known subclasses: " + ", ".join(class_paths)
@@ -738,7 +747,6 @@ def adapt_typehints(
     prev_val=None,
     orig_val=None,
     append=False,
-    list_item=False,
     enable_path=False,
     sub_add_kwargs=None,
     default=None,
@@ -834,7 +842,7 @@ def adapt_typehints(
     # Union
     elif typehint_origin == Union:
         vals = []
-        sorted_subtypes = sort_subtypes_for_union(subtypehints, val, append)
+        sorted_subtypes = sort_subtypes_for_union(subtypehints, val, prev_val, append)
         for subtype in sorted_subtypes:
             try:
                 vals.append(adapt_typehints(val, subtype, **adapt_kwargs))
@@ -898,7 +906,7 @@ def adapt_typehints(
                 else:
                     adapt_kwargs_n = deepcopy(adapt_kwargs)
                 with change_to_path_dir(list_path):
-                    val[n] = adapt_typehints(v, subtypehints[0], list_item=True, **adapt_kwargs_n)
+                    val[n] = adapt_typehints(v, subtypehints[0], **adapt_kwargs_n)
 
     # Dict, Mapping
     elif typehint_origin in mapping_origin_types:
@@ -947,17 +955,6 @@ def adapt_typehints(
                 required_keys.difference_update(
                     {k for k, v in typehint.__annotations__.items() if get_typehint_origin(v) in not_required_types}
                 )
-            # The standard library TypedDict in Python 3.8 does not store runtime information
-            # about which (if any) keys are optional. See https://bugs.python.org/issue38834.
-            # Thus, fall back to totality and explicitly Required keys
-            elif typehint.__total__:
-                required_keys = {
-                    k for k, v in typehint.__annotations__.items() if get_typehint_origin(v) not in not_required_types
-                }
-            else:
-                required_keys = {
-                    k for k, v in typehint.__annotations__.items() if get_typehint_origin(v) in required_types
-                }
             missing_keys = required_keys - val.keys()
             if missing_keys:
                 raise_unexpected_value(f"Missing required keys: {missing_keys}", val)
@@ -978,11 +975,15 @@ def adapt_typehints(
         val = adapt_typehints(val, subtypehints[0], **adapt_kwargs)
 
     # Callable
-    elif typehint_origin in callable_origin_types or typehint in callable_origin_types:
+    elif (
+        typehint_origin in callable_origin_types
+        or typehint in callable_origin_types
+        or is_instance_factory_protocol(typehint, logger)
+    ):
         if serialize:
             if is_subclass_spec(val):
-                val, _, num_partial_args = adapt_partial_callable_class(typehint, val)
-                val = adapt_class_type(val, True, False, sub_add_kwargs, skip_args=num_partial_args)
+                val, partial_skip_args = adapt_partial_callable_class(typehint, val)
+                val = adapt_class_type(val, True, False, sub_add_kwargs, partial_skip_args=partial_skip_args)
             else:
                 val = object_path_serializer(val)
         else:
@@ -1011,12 +1012,13 @@ def adapt_typehints(
                         raise ImportError(
                             f"Dict must include a class_path and optionally init_args, but got {val_input}"
                         )
-                    val, partial_classes, num_partial_args = adapt_partial_callable_class(typehint, val)
+                    val, partial_skip_args = adapt_partial_callable_class(typehint, val)
                     val_class = import_object(val["class_path"])
-                    if inspect.isclass(val_class) and not (partial_classes or callable_instances(val_class)):
+                    if inspect.isclass(val_class) and not (partial_skip_args or callable_instances(val_class)):
+                        base_type = get_callable_return_type(typehint) or typehint
                         raise ImportError(
                             f"Expected '{val['class_path']}' to be a class that instantiates into callable "
-                            f"or a subclass of {partial_classes}."
+                            f"or a subclass of {base_type}."
                         )
                     val["class_path"] = get_import_path(val_class)
                     val = adapt_class_type(
@@ -1024,36 +1026,14 @@ def adapt_typehints(
                         False,
                         instantiate_classes,
                         sub_add_kwargs,
-                        skip_args=num_partial_args,
-                        partial_classes=partial_classes,
+                        partial_skip_args=partial_skip_args,
                         prev_val=prev_val,
                     )
             except (ImportError, AttributeError, ArgumentError) as ex:
                 raise_unexpected_value(f"Type {typehint} expects a function or a callable class: {ex}", val, ex)
 
-    # Dataclass-like
-    elif is_dataclass_like(typehint):
-        if isinstance(prev_val, (dict, Namespace)):
-            assert isinstance(sub_add_kwargs, dict)
-            sub_add_kwargs["default"] = prev_val
-        parser = ActionTypeHint.get_class_parser(typehint, sub_add_kwargs=sub_add_kwargs)
-        if instantiate_classes:
-            init_args = parser.instantiate_classes(val)
-            return typehint(**init_args)
-        if serialize:
-            val = load_value(parser.dump(val, **dump_kwargs.get()))
-        elif isinstance(val, (dict, Namespace)):
-            if is_subclass_spec(val) and get_import_path(typehint) == val.get("class_path"):
-                val = val.get("init_args")
-            val = parser.parse_object(val, defaults=sub_defaults.get() or list_item)
-        elif isinstance(val, NestedArg):
-            prev_val = prev_val if isinstance(prev_val, Namespace) else None
-            val = parser.parse_args([f"--{val.key}={val.val}"], namespace=prev_val)
-        else:
-            raise_unexpected_value(f"Type {typehint} expects a dict or Namespace", val)
-
     # Subclass
-    elif not hasattr(typehint, "__origin__") and inspect.isclass(typehint):
+    elif inspect.isclass(typehint_origin):
         if is_instance_or_supports_protocol(val, typehint):
             if serialize:
                 val = serialize_class_instance(val)
@@ -1064,12 +1044,21 @@ def adapt_typehints(
         prev_implicit_defaults = False
         if prev_val is None and not inspect.isabstract(typehint) and not is_protocol(typehint):
             with suppress(ValueError):
-                prev_val = Namespace(class_path=get_import_path(typehint))  # implicit class_path
+                # implicit prev_val class_path
+                prev_val = Namespace(class_path=get_import_path(typehint))
                 if parse_kwargs.get().get("defaults") is True:
                     prev_implicit_defaults = True
 
+        if isinstance(prev_val, (dict, Namespace)) and "class_path" not in prev_val:
+            # implicit prev_val class_path and init_args
+            prev_val = Namespace(class_path=get_import_path(typehint), init_args=Namespace(prev_val))
+
         val_input = val
         val = subclass_spec_as_namespace(val, prev_val)
+        if val and not is_subclass_spec(val) and "init_args" not in val:
+            # implicit val class_path
+            val = Namespace(class_path=get_import_path(typehint), init_args=val)
+
         if not is_subclass_spec(val):
             msg = "Does not implement protocol" if is_protocol(typehint) else "Not a valid subclass of"
             raise_unexpected_value(
@@ -1077,7 +1066,8 @@ def adapt_typehints(
                 "Subclass types expect one of:\n"
                 "- a class path (str)\n"
                 "- a dict with class_path entry\n"
-                "- a dict without class_path but with init_args entry (class path given previously)"
+                "- a dict without class_path but with init_args entry (class path given previously)\n"
+                "- a dict with parameters accepted by the base class (implicit class_path)"
             )
 
         try:
@@ -1107,7 +1097,14 @@ def adapt_typehints(
                 msg = "implement protocol" if is_protocol(typehint) else "correspond to a subclass of"
                 raise_unexpected_value(f"Import path {val['class_path']} does not {msg} {typehint.__name__}")
             val["class_path"] = class_path
-            val = adapt_class_type(val, serialize, instantiate_classes, sub_add_kwargs, prev_val=prev_val)
+            val = adapt_class_type(
+                val,
+                serialize,
+                instantiate_classes,
+                sub_add_kwargs,
+                prev_val=prev_val,
+                typehint=typehint,
+            )
         except (ImportError, AttributeError, AssertionError, ArgumentError) as ex:
             class_path = val if isinstance(val, str) else val["class_path"]
             error = indent_text(str(ex))
@@ -1118,8 +1115,6 @@ def adapt_typehints(
         return adapt_typehints(val, get_alias_target(typehint), **adapt_kwargs)
 
     else:
-        if str(typehint) == "+VT_co":
-            return val  # required for typing.Mapping in python 3.8
         raise RuntimeError(f"The code should never reach here: typehint={typehint}")  # pragma: no cover
 
     return val
@@ -1182,7 +1177,16 @@ def is_subclass_or_implements_protocol(value, class_type) -> bool:
 def is_instance_or_supports_protocol(value, class_type):
     if is_protocol(class_type):
         return is_subclass_or_implements_protocol(value.__class__, class_type)
-    return isinstance(value, class_type)
+    return is_instance(value, class_type)
+
+
+def is_instance_factory_protocol(class_type, logger=None):
+    if not is_protocol(class_type) or not callable_instances(class_type):
+        return False
+    from ._postponed_annotations import get_return_type
+
+    return_type = get_return_type(class_type.__call__, logger)
+    return ActionTypeHint.is_subclass_typehint(return_type)
 
 
 def is_subclass_spec(val):
@@ -1227,55 +1231,87 @@ def subclass_spec_as_namespace(val, prev_val=None):
 
 def get_callable_return_type(typehint):
     return_type = None
-    args = getattr(typehint, "__args__", None)
-    if isinstance(args, tuple) and len(args) > 0:
-        return_type = args[-1]
+    if is_instance_factory_protocol(typehint):
+        from ._postponed_annotations import get_return_type
+
+        return_type = get_return_type(typehint.__call__)
+    elif get_typehint_origin(typehint) in callable_origin_types:
+        args = getattr(typehint, "__args__", None)
+        if isinstance(args, tuple) and len(args) > 0:
+            return_type = args[-1]
     return return_type
 
 
-def is_single_subclass_typehint(typehint, typehint_origin):
-    return (
-        inspect.isclass(typehint)
+def is_single_class_type(typehint, typehint_origin, closed_class):
+    if not (
+        (
+            (inspect.isclass(typehint) and typehint_origin is None)
+            or (is_generic_class(typehint) and inspect.isclass(typehint.__origin__))
+        )
         and typehint not in leaf_or_root_types
         and not get_registered_type(typehint)
         and not is_pydantic_type(typehint)
-        and not is_dataclass_like(typehint)
-        and typehint_origin is None
         and not is_subclass(typehint, (Path, Enum))
-    )
+        and getattr(typehint_origin, "__module__", "") != "builtins"
+    ):
+        return False
+    if not closed_class:
+        return not is_not_subclass_type(typehint)
+    return True
 
 
-def yield_subclass_types(typehint, also_lists=False, callable_return=False):
+is_single_subclass_type = partial(is_single_class_type, closed_class=False)
+is_single_subclass_or_closed_type = partial(is_single_class_type, closed_class=True)
+
+
+def yield_class_types(typehint, is_single, also_lists=False, callable_return=False):
     typehint = typehint_from_action(typehint)
     if typehint is None:
         return
     typehint = get_unaliased_type(get_optional_arg(get_unaliased_type(typehint)))
     typehint_origin = get_typehint_origin(typehint)
-    if callable_return and typehint_origin in callable_origin_types:
+    kwargs = {"is_single": is_single, "also_lists": also_lists, "callable_return": callable_return}
+    if callable_return and (typehint_origin in callable_origin_types or is_instance_factory_protocol(typehint)):
         return_type = get_callable_return_type(typehint)
         if return_type:
-            k = {"also_lists": also_lists, "callable_return": callable_return}
-            yield from yield_subclass_types(return_type, **k)
+            yield from yield_class_types(return_type, **kwargs)
     elif typehint_origin == Union or (also_lists and typehint_origin in sequence_origin_types):
-        k = {"also_lists": also_lists, "callable_return": callable_return}
         for subtype in typehint.__args__:
-            yield from yield_subclass_types(subtype, **k)
-    if is_single_subclass_typehint(typehint, typehint_origin):
+            yield from yield_class_types(subtype, **kwargs)
+    if is_single(typehint, typehint_origin):
         yield typehint
 
 
 def get_subclass_types(typehint, also_lists=False, callable_return=False):
-    types = tuple(yield_subclass_types(typehint, also_lists=also_lists, callable_return=callable_return))
+    types = tuple(
+        yield_class_types(
+            typehint, is_single=is_single_subclass_type, also_lists=also_lists, callable_return=callable_return
+        )
+    )
+    return types or None
+
+
+def get_subclass_or_closed_types(typehint, also_lists=False, callable_return=False):
+    types = tuple(
+        yield_class_types(
+            typehint,
+            is_single=is_single_subclass_or_closed_type,
+            also_lists=also_lists,
+            callable_return=callable_return,
+        )
+    )
     return types or None
 
 
 def get_subclass_names(typehint, callable_return=False):
-    return tuple(t.__name__ for t in yield_subclass_types(typehint, callable_return=callable_return))
+    return tuple(
+        t.__name__
+        for t in yield_class_types(typehint, is_single=is_single_subclass_type, callable_return=callable_return)
+    )
 
 
 def adapt_partial_callable_class(callable_type, subclass_spec):
-    partial_classes = False
-    num_partial_args = 0
+    partial_skip_args = None
     return_type = get_callable_return_type(callable_type)
     if return_type:
         subclass_types = get_subclass_types(return_type)
@@ -1283,9 +1319,18 @@ def adapt_partial_callable_class(callable_type, subclass_spec):
         if subclass_types and is_subclass(class_type, subclass_types):
             subclass_spec = subclass_spec.clone()
             subclass_spec["class_path"] = get_import_path(class_type)
-            partial_classes = True
-            num_partial_args = len(callable_type.__args__) - 1
-    return subclass_spec, partial_classes, num_partial_args
+            if is_protocol(callable_type):
+                from ._parameter_resolvers import get_signature_parameters
+
+                params = get_signature_parameters(callable_type, "__call__")
+                partial_skip_args = set()
+                positionals = [p for p in params if "POSITIONAL_ONLY" in str(p.kind)]
+                if positionals:
+                    partial_skip_args.add(len(positionals))
+                partial_skip_args.update(p.name for p in params if "POSITIONAL_ONLY" not in str(p.kind))
+            else:
+                partial_skip_args = {len(callable_type.__args__) - 1}
+    return subclass_spec, partial_skip_args
 
 
 def get_all_subclass_paths(cls: Type) -> List[str]:
@@ -1317,8 +1362,6 @@ def get_all_subclass_paths(cls: Type) -> List[str]:
             add_subclasses(subclass)
 
     if get_typehint_origin(cls) in callable_origin_types:
-        if len(getattr(cls, "__args__", [])) < 2:
-            return subclass_list
         cls = cls.__args__[-1]
 
     if get_typehint_origin(cls) in {Union, Type, type}:
@@ -1331,9 +1374,15 @@ def get_all_subclass_paths(cls: Type) -> List[str]:
     return subclass_list
 
 
-def resolve_class_path_by_name(cls: Type, name: str) -> str:
+def resolve_class_path_by_name(cls: Union[Type, Tuple[Type]], name: str) -> str:
     class_path = name
     if "." not in class_path:
+        if isinstance(cls, tuple):
+            for cls_n in cls:
+                class_path = resolve_class_path_by_name(cls_n, name)
+                if "." in class_path:
+                    break
+            return class_path
         subclass_dict = defaultdict(list)
         for subclass in get_all_subclass_paths(cls):
             subclass_name = subclass.rsplit(".", 1)[1]
@@ -1372,7 +1421,7 @@ def discard_init_args_on_class_path_change(parser_or_action, prev_val, value):
             parser = ActionTypeHint.get_class_parser(value["class_path"], sub_add_kwargs)
         del_args = {}
         prev_val = subclass_spec_as_namespace(prev_val)
-        for key, val in list(prev_val.init_args.__dict__.items()):
+        for key, val in list(prev_val.init_args.items(branches=True, nested=False)):
             action = _find_action(parser, key)
             if action:
                 with parser_context(lenient_check=False, load_value_mode=parser.parser_mode):
@@ -1390,12 +1439,21 @@ def discard_init_args_on_class_path_change(parser_or_action, prev_val, value):
 
 
 def adapt_class_type(
-    value, serialize, instantiate_classes, sub_add_kwargs, prev_val=None, skip_args=0, partial_classes=False
+    value,
+    serialize,
+    instantiate_classes,
+    sub_add_kwargs,
+    prev_val=None,
+    partial_skip_args=None,
+    typehint=None,
 ):
     prev_val = subclass_spec_as_namespace(prev_val)
     value = subclass_spec_as_namespace(value)
-    val_class = import_object(value.class_path)
-    parser = ActionTypeHint.get_class_parser(val_class, sub_add_kwargs, skip_args=skip_args)
+    if is_generic_class(typehint):
+        val_class = typehint
+    else:
+        val_class = import_object(value.class_path)
+    parser = ActionTypeHint.get_class_parser(val_class, sub_add_kwargs, skip_args=partial_skip_args)
 
     # No need to re-create the linked arg but just "inform" the corresponding parser actions that it exists upstream.
     for target in sub_add_kwargs.get("linked_targets", []):
@@ -1428,7 +1486,7 @@ def adapt_class_type(
 
         instantiator_fn = get_class_instantiator()
 
-        if partial_classes:
+        if partial_skip_args:
             return partial(
                 instantiator_fn,
                 val_class,
@@ -1469,6 +1527,10 @@ def adapt_class_type(
                 with suppress(get_loader_exceptions()):
                     val = load_value(val, simple_types=True)
             value["dict_kwargs"][key] = val
+
+    if is_not_subclass_type(typehint) and value.class_path == get_import_path(typehint):
+        value = Namespace({**value.get("init_args", {}), **value.get("dict_kwargs", {})})
+
     return value
 
 
@@ -1478,7 +1540,7 @@ def adapt_classes_any(val, serialize, instantiate_classes, sub_add_kwargs):
         val = subclass_spec_as_namespace(val)
         init_args = val.get("init_args")
         if init_args and not instantiate_classes:
-            for subkey, subval in init_args.__dict__.items():
+            for subkey, subval in init_args.items(branches=True, nested=False):
                 init_args[subkey] = adapt_classes_any(subval, serialize, instantiate_classes, sub_add_kwargs)
             val["init_args"] = init_args
         try:
@@ -1494,7 +1556,7 @@ def adapt_classes_any(val, serialize, instantiate_classes, sub_add_kwargs):
     return val
 
 
-def sort_subtypes_for_union(subtypes, val, append):
+def sort_subtypes_for_union(subtypes, val, prev_val, append):
     if len(subtypes) > 1:
         if isinstance(val, str):
             key_fn = lambda x: (
@@ -1504,8 +1566,12 @@ def sort_subtypes_for_union(subtypes, val, append):
         else:
             key_fn = lambda x: x != NoneType
         subtypes = sorted(subtypes, key=key_fn)
-        if append:
-            subtypes = sorted(subtypes, key=lambda x: get_typehint_origin(x) not in sequence_origin_types)
+        if append or (isinstance(prev_val, list) and isinstance(val, NestedArg)):
+            key_fn = lambda x: (
+                x != NoneType,
+                get_typehint_origin(x) not in sequence_origin_types,
+            )
+            subtypes = sorted(subtypes, key=key_fn)
     return subtypes
 
 
@@ -1628,9 +1694,10 @@ class LazyInitBaseClass:
                 self.__dict__[name] = seen_methods[id(member)]
             else:
                 lazy_method = partial(self._lazy_init_then_call_method, name)
-                self.__dict__[name] = lazy_method
                 if name == "__call__":
+                    lazy_method = staticmethod(lazy_method)  # type: ignore[assignment]
                     self._lazy.__call__ = lazy_method  # type: ignore[method-assign]
+                self.__dict__[name] = lazy_method
                 seen_methods[id(member)] = lazy_method
 
     def _lazy_init(self):
