@@ -12,7 +12,7 @@ from unittest.mock import patch
 
 import pytest
 
-from jsonargparse import ActionConfigFile, ActionJsonSchema, ActionYesNo
+from jsonargparse import ActionJsonSchema, ActionYesNo
 from jsonargparse._common import parser_context
 from jsonargparse.typing import Email, Path_fr, PositiveFloat, PositiveInt
 from jsonargparse_tests.conftest import (
@@ -58,6 +58,22 @@ def complete_line(parser, value):
     return out.getvalue(), err.getvalue()
 
 
+def test_handle_completions(parser):
+    parser.add_argument("--option")
+    with (
+        patch("argcomplete.autocomplete") as mock,
+        patch.dict(
+            os.environ,
+            {
+                "_ARGCOMPLETE": "1",
+            },
+        ),
+    ):
+        parser.parse_args([])
+    assert mock.called
+    assert mock.call_args[0][0] is parser
+
+
 def test_complete_nested_one_option(parser):
     parser.add_argument("--group1.op")
     out, err = complete_line(parser, "tool.py --group1")
@@ -102,7 +118,7 @@ def test_stderr_instruction_simple_types(parser, value, expected):
 
 @skip_if_not_posix
 def test_action_config_file(parser, tmp_cwd):
-    parser.add_argument("--cfg", action=ActionConfigFile)
+    parser.add_argument("--cfg", action="config")
     Path("file1").touch()
     Path("config.yaml").touch()
 
