@@ -17,7 +17,7 @@ import pytest
 
 from jsonargparse import CLI, auto_cli, auto_parser, capture_parser, lazy_instance
 from jsonargparse._namespace import Namespace
-from jsonargparse._optionals import docstring_parser_support, ruyaml_support
+from jsonargparse._optionals import docstring_parser_support, ruamel_support
 from jsonargparse.typing import final
 from jsonargparse_tests.conftest import json_or_yaml_dump, json_or_yaml_load, skip_if_docstring_parser_unavailable
 
@@ -157,7 +157,6 @@ def conditional_function(fn: "Literal['A', 'B']", *args, **kwargs):
     raise NotImplementedError(fn)
 
 
-@pytest.mark.skipif(condition=sys.version_info < (3, 9), reason="python>=3.9 is required")
 def test_literal_conditional_function():
     out = get_cli_stdout(conditional_function, args=["--help"])
     assert "Conditional arguments" in out
@@ -352,7 +351,7 @@ def test_function_and_class_print_config_before_subcommands():
 
 
 @skip_if_docstring_parser_unavailable
-@pytest.mark.skipif(not ruyaml_support, reason="ruyaml not installed")
+@pytest.mark.skipif(not ruamel_support, reason="ruamel.yaml package is required")
 def test_function_and_class_print_config_comments():
     out = get_cli_stdout([cmd1, Cmd2, cmd3], args=["--print_config=comments", "Cmd2", "method2"])
     assert "# Description of Cmd2" in out
