@@ -1,21 +1,21 @@
 from __future__ import annotations
 
+import json
 from calendar import Calendar, TextCalendar
 from dataclasses import dataclass
+from importlib.util import find_spec
 from typing import Any, Callable, List, Mapping, Optional, Union
 
 import pytest
-import yaml
 
 from jsonargparse import (
-    ActionConfigFile,
     ArgumentError,
     ArgumentParser,
     Namespace,
     lazy_instance,
 )
 from jsonargparse._optionals import docstring_parser_support
-from jsonargparse_tests.conftest import get_parse_args_stdout, get_parser_help
+from jsonargparse_tests.conftest import get_parse_args_stdout, get_parser_help, json_or_yaml_dump, json_or_yaml_load
 
 # tests for links applied on parse
 
@@ -25,16 +25,16 @@ def test_on_parse_help_target_lacking_type_and_help(parser):
     parser.add_argument("--b")
     parser.link_arguments("a", "b")
     help_str = get_parser_help(parser)
-    assert "Target argument 'b' lacks type and help" in help_str
+    assert "Target 'b' lacks type and help" in help_str
 
 
 def test_on_parse_shallow_print_config(parser):
-    parser.add_argument("--cfg", action=ActionConfigFile)
+    parser.add_argument("--cfg", action="config")
     parser.add_argument("--a", type=int, default=0)
     parser.add_argument("--b", type=str)
     parser.link_arguments("a", "b")
     out = get_parse_args_stdout(parser, ["--print_config"])
-    assert yaml.safe_load(out) == {"a": 0}
+    assert json_or_yaml_load(out) == {"a": 0}
 
 
 def test_on_parse_subcommand_failing_compute_fn(parser, subparser, subtests):
@@ -46,18 +46,18 @@ def test_on_parse_subcommand_failing_compute_fn(parser, subparser, subtests):
     subparser.add_argument("--a", type=int, default=0)
     subparser.add_argument("--b", type=str)
     subparser.link_arguments("a", "b", to_str)
-    subparser.add_argument("--config", action=ActionConfigFile)
+    subparser.add_argument("--config", action="config")
     subcommands = parser.add_subcommands()
     subcommands.add_subcommand("sub", subparser)
 
     with subtests.test("parse_args"):
-        with pytest.raises(ValueError) as ctx:
+        with pytest.raises(ArgumentError) as ctx:
             parser.parse_args(["sub"])
         ctx.match("Call to compute_fn of link 'to_str.*failed: value is empty")
 
     with subtests.test("print_config"):
         out = get_parse_args_stdout(parser, ["sub", "--print_config"])
-        assert yaml.safe_load(out) == {"a": 0}
+        assert json_or_yaml_load(out) == {"a": 0}
 
 
 def test_on_parse_compute_fn_single_arguments(parser, subtests):
@@ -74,11 +74,11 @@ def test_on_parse_compute_fn_single_arguments(parser, subtests):
         assert cfg.b.v2 == cfg.a.v1 * cfg.a.v2
 
     with subtests.test("dump removal of target"):
-        dump = yaml.safe_load(parser.dump(cfg))
+        dump = json_or_yaml_load(parser.dump(cfg))
         assert dump == {"a": {"v1": 2, "v2": -5}}
 
     with subtests.test("dump keep target"):
-        dump = yaml.safe_load(parser.dump(cfg, skip_link_targets=False))
+        dump = json_or_yaml_load(parser.dump(cfg, skip_link_targets=False))
         assert dump == {"a": {"v1": 2, "v2": -5}, "b": {"v2": -10}}
 
     with subtests.test("invalid compute_fn result type"):
@@ -88,7 +88,7 @@ def test_on_parse_compute_fn_single_arguments(parser, subtests):
 
 
 def test_on_parse_compute_fn_subclass_spec(parser, subtests):
-    parser.add_argument("--cfg", action=ActionConfigFile)
+    parser.add_argument("--cfg", action="config")
     parser.add_argument("--cal1", type=Calendar, default=lazy_instance(TextCalendar))
     parser.add_argument("--cal2", type=Calendar, default=lazy_instance(Calendar))
     parser.link_arguments(
@@ -111,7 +111,10 @@ def test_on_parse_compute_fn_subclass_spec(parser, subtests):
         parser.set_defaults(cal1=None)
         with pytest.raises(ArgumentError) as ctx:
             parser.parse_args(["--cal1.firstweekday=-"])
-        ctx.match('Parser key "cal1"')
+        if find_spec("typeshed_client"):
+            ctx.match('Parser key "cal1"')
+        else:
+            ctx.match("Call to compute_fn of link")
 
 
 class ClassA:
@@ -153,12 +156,12 @@ def test_on_parse_add_class_arguments(subtests):
         cfg = parser.parse_args(["--a.v1=11", "--a.v2=7"])
         assert 7 == cfg.b.v1
         assert 11 + 7 == cfg.b.v2
-        dump = yaml.safe_load(parser.dump(cfg))
+        dump = json_or_yaml_load(parser.dump(cfg))
         assert dump == {"a": {"v1": 11, "v2": 7}, "b": {"v3": 2}}
 
     with subtests.test("dump keep targets"):
         cfg = parser.parse_args(["--a.v1=11", "--a.v2=7"])
-        dump = yaml.safe_load(parser.dump(cfg, skip_link_targets=False))
+        dump = json_or_yaml_load(parser.dump(cfg, skip_link_targets=False))
         assert dump == {"a": {"v1": 11, "v2": 7}, "b": {"v3": 2, "v1": 7, "v2": 18}}
 
     with subtests.test("argument error"):
@@ -193,17 +196,17 @@ def test_on_parse_add_subclass_arguments(parser, subtests):
     }
 
     with subtests.test("compute_fn result"):
-        cfg = parser.parse_args([f"--s1={s1_value}", f"--s2={__name__}.ClassS2"])
+        cfg = parser.parse_args([f"--s1={json.dumps(s1_value)}", f"--s2={__name__}.ClassS2"])
         assert cfg.s2.init_args.v3 == 4
         assert cfg.s2.init_args.v3 == cfg.s1.init_args.v1 + cfg.s1.init_args.v2
 
     with subtests.test("dump removal of target"):
-        cfg = parser.parse_args([f"--s1={s1_value}", f"--s2={__name__}.ClassS2"])
-        dump = yaml.safe_load(parser.dump(cfg))
+        cfg = parser.parse_args([f"--s1={json.dumps(s1_value)}", f"--s2={__name__}.ClassS2"])
+        dump = json_or_yaml_load(parser.dump(cfg))
         assert dump["s2"] == {"class_path": f"{__name__}.ClassS2"}
 
     with subtests.test("dump keep target"):
-        dump = yaml.safe_load(parser.dump(cfg, skip_link_targets=False))
+        dump = json_or_yaml_load(parser.dump(cfg, skip_link_targets=False))
         assert dump["s2"] == {"class_path": f"{__name__}.ClassS2", "init_args": {"v3": 4}}
 
     with subtests.test("compute_fn invalid result type"):
@@ -250,11 +253,11 @@ def test_on_parse_subclass_target_in_list(parser):
     parser.link_arguments("trainer.save_dir", "trainer.logger.init_args.save_dir")
     cfg = parser.parse_args([])
     assert cfg.trainer == Namespace(logger=[], save_dir=None)
-    cfg = parser.parse_args(["--trainer.save_dir=logs", "--trainer.logger=[Logger]"])
+    cfg = parser.parse_args(["--trainer.save_dir=logs", '--trainer.logger=["Logger"]'])
     assert cfg.trainer.save_dir == "logs"
     assert len(cfg.trainer.logger) == 1
     assert cfg.trainer.logger[0].init_args == Namespace(save_dir="logs")
-    cfg = parser.parse_args(["--trainer.save_dir=logs", "--trainer.logger=[Logger, Logger]"])
+    cfg = parser.parse_args(["--trainer.save_dir=logs", '--trainer.logger=["Logger", "Logger"]'])
     assert len(cfg.trainer.logger) == 2
     assert all(x.init_args == Namespace(save_dir="logs") for x in cfg.trainer.logger)
 
@@ -276,7 +279,7 @@ def test_on_parse_subclass_target_in_union_list(parser):
     cfg = parser.parse_args(["--trainer.save_dir=logs", "--trainer.logger=Logger"])
     assert cfg.trainer.save_dir == "logs"
     assert cfg.trainer.logger.init_args == Namespace(save_dir="logs")
-    cfg = parser.parse_args(["--trainer.save_dir=logs", "--trainer.logger=[Logger, Logger]"])
+    cfg = parser.parse_args(["--trainer.save_dir=logs", '--trainer.logger=["Logger", "Logger"]'])
     assert len(cfg.trainer.logger) == 2
     assert all(x.init_args == Namespace(save_dir="logs") for x in cfg.trainer.logger)
 
@@ -298,7 +301,7 @@ def test_on_parse_subclass_target_in_optional_list(parser):
     cfg = parser.parse_args(["--trainer.save_dir=logs", "--trainer.logger+=Logger"])
     assert cfg.trainer.save_dir == "logs"
     assert cfg.trainer.logger[0].init_args == Namespace(save_dir="logs")
-    cfg = parser.parse_args(["--trainer.save_dir=logs", "--trainer.logger=[Logger, Logger]"])
+    cfg = parser.parse_args(["--trainer.save_dir=logs", '--trainer.logger=["Logger", "Logger"]'])
     assert len(cfg.trainer.logger) == 2
     assert all(x.init_args == Namespace(save_dir="logs") for x in cfg.trainer.logger)
 
@@ -326,7 +329,7 @@ def test_on_parse_add_subclass_arguments_with_instantiate_false(parser, subtests
     }
 
     with subtests.test("parse_args"):
-        cfg = parser.parse_args([f"--f={f_value}", f"--c={c_value}"])
+        cfg = parser.parse_args([f"--f={json.dumps(f_value)}", f"--c={json.dumps(c_value)}"])
         assert cfg.c.as_dict() == {
             "class_path": "calendar.Calendar",
             "init_args": {"firstweekday": 3},
@@ -341,11 +344,11 @@ def test_on_parse_add_subclass_arguments_with_instantiate_false(parser, subtests
         assert init.f.c.firstweekday == 3
 
     with subtests.test("dump removal of target"):
-        dump = yaml.safe_load(parser.dump(cfg))
+        dump = json_or_yaml_load(parser.dump(cfg))
         assert "c" not in dump["f"]["init_args"]
 
     with subtests.test("dump keep target"):
-        dump = yaml.safe_load(parser.dump(cfg, skip_link_targets=False))
+        dump = json_or_yaml_load(parser.dump(cfg, skip_link_targets=False))
         assert dump["f"]["init_args"]["c"] == {"class_path": "calendar.Calendar", "init_args": {"firstweekday": 3}}
 
 
@@ -377,7 +380,7 @@ def test_on_parse_add_subclass_arguments_compute_fn_return_dict(parser):
         },
     }
 
-    cfg = parser.parse_args([f"--d={d_value}", f"--c={c_value}"])
+    cfg = parser.parse_args([f"--d={json.dumps(d_value)}", f"--c={json.dumps(c_value)}"])
     assert cfg.d.init_args.a1 == c_value
     assert cfg.d.init_args.a2 == c_value
 
@@ -435,10 +438,25 @@ def test_on_parse_save_required_target_subclass_param(parser, tmp_cwd):
     parser.link_arguments("a.a", "c.init_args.b.a")
     cfg = parser.parse_args(["--a.a=1", f"--c={__name__}.RequiredTargetC"])
     parser.save(cfg, "config.yaml")
-    saved = yaml.safe_load((tmp_cwd / "config.yaml").read_text())
+    saved = json_or_yaml_load((tmp_cwd / "config.yaml").read_text())
     assert saved == {"a": {"a": 1}, "c": {"class_path": f"{__name__}.RequiredTargetC", "init_args": {}}}
 
 
+def test_on_parse_save_required_target_entire_dataclass(parser, tmp_cwd):
+    parser.add_class_arguments(RequiredTargetA, "a")
+    parser.add_subclass_arguments(RequiredTargetC, "c")
+    parser.link_arguments("a", "c.init_args.b")
+    cfg = parser.parse_args(["--a.a=1", f"--c={__name__}.RequiredTargetC"])
+    expected = {"a": {"a": 1}, "c": {"class_path": f"{__name__}.RequiredTargetC"}}
+    parser.save(cfg, "config.yaml", multifile=False)
+    saved = json_or_yaml_load((tmp_cwd / "config.yaml").read_text())
+    assert saved == expected
+    (tmp_cwd / "config.yaml").unlink()
+    parser.save(cfg, "config.yaml", multifile=True)
+    saved = json_or_yaml_load((tmp_cwd / "config.yaml").read_text())
+    assert saved == expected
+
+
 class Optimizer:
     def __init__(self, params: List[int], lr: float):
         self.params = params
@@ -464,6 +482,16 @@ def test_on_parse_nested_callable(parser):
     assert cfg.model.init_args.optimizer.init_args == Namespace(lr=0.01)
 
 
+def test_on_parse_type_skip_link_targets_dump(parser):
+    parser.add_argument("--t1", type=type)
+    parser.add_argument("--t2", type=type)
+    parser.link_arguments("t1", "t2")
+
+    cfg = parser.parse_args([f"--t1={__name__}.Model"])
+    dump = json_or_yaml_load(parser.dump(cfg, skip_link_targets=False))
+    assert dump["t2"] == f"{__name__}.Model"
+
+
 # tests for links applied on instantiate
 
 
@@ -640,7 +668,7 @@ def test_on_parse_link_entire_subclass(parser):
     parser.link_arguments("n.calendar", "q.calendar", apply_on="parse")
 
     cal = {"class_path": "Calendar", "init_args": {"firstweekday": 4}}
-    cfg = parser.parse_args([f"--n.calendar={cal}", "--q.q2=7"])
+    cfg = parser.parse_args([f"--n.calendar={json.dumps(cal)}", "--q.q2=7"])
     assert cfg.n.calendar == cfg.q.calendar
     assert cfg.q.q2 == 7
 
@@ -761,7 +789,7 @@ def test_on_instantiate_within_deep_subclass(parser, caplog):
     parser.logger = {"level": "DEBUG"}
     parser.logger.handlers = [caplog.handler]
 
-    parser.add_argument("--cfg", action=ActionConfigFile)
+    parser.add_argument("--cfg", action="config")
     parser.add_argument("--model", type=WithinDeepModel)
     parser.link_arguments(
         "model.encoder.output_channels",
@@ -769,7 +797,7 @@ def test_on_instantiate_within_deep_subclass(parser, caplog):
         apply_on="instantiate",
     )
 
-    cfg = parser.parse_args([f"--cfg={within_deep_config}"])
+    cfg = parser.parse_args([f"--cfg={json.dumps(within_deep_config)}"])
     init = parser.instantiate_classes(cfg)
     assert isinstance(init.model, WithinDeepModel)
     assert isinstance(init.model.encoder, WithinDeepSource)
@@ -795,7 +823,7 @@ def test_on_instantiate_within_deeper_subclass(parser, caplog):
     parser.logger = {"level": "DEBUG"}
     parser.logger.handlers = [caplog.handler]
 
-    parser.add_argument("--cfg", action=ActionConfigFile)
+    parser.add_argument("--cfg", action="config")
     parser.add_subclass_arguments(WithinDeeperSystem, "system")
     parser.link_arguments(
         "system.model.encoder.output_channels",
@@ -803,7 +831,7 @@ def test_on_instantiate_within_deeper_subclass(parser, caplog):
         apply_on="instantiate",
     )
 
-    cfg = parser.parse_args([f"--cfg={within_deeper_config}"])
+    cfg = parser.parse_args([f"--cfg={json.dumps(within_deeper_config)}"])
     init = parser.instantiate_classes(cfg)
     assert isinstance(init.system, WithinDeeperSystem)
     assert isinstance(init.system.model, WithinDeepModel)
@@ -813,6 +841,147 @@ def test_on_instantiate_within_deeper_subclass(parser, caplog):
     assert "Applied link 'encoder.output_channels --> decoder.init_args.input_channels'" in caplog.text
 
 
+class SourceA:
+    def __init__(self, param_a: str):
+        self.attr_a = param_a
+
+
+class SourceB:
+    def __init__(self, param_b: str):
+        self.attr_b = param_b
+
+
+class HierarchyGrandchild:
+    def __init__(self, param_grandchild: str):
+        self.attr_grandchild = param_grandchild
+
+
+class HierarchyChild:
+    def __init__(self, param_child: str, grandchild: HierarchyGrandchild):
+        self.attr_child = param_child
+        self.grandchild = grandchild
+
+
+class HierarchyRoot:
+    def __init__(self, child: HierarchyChild):
+        self.child = child
+
+
+def get_source_a_attr(source_a):
+    assert isinstance(source_a, SourceA)
+    return source_a.attr_a
+
+
+def test_on_instantiate_targets_share_parent(parser):
+    config = {
+        "source_a": {
+            "param_a": "value a",
+        },
+        "source_b": {
+            "param_b": "value b",
+        },
+        "root": {
+            "child": {
+                "class_path": "HierarchyChild",
+                "init_args": {
+                    "grandchild": {
+                        "class_path": "HierarchyGrandchild",
+                    },
+                },
+            },
+        },
+    }
+    parser.add_argument("--config", action="config")
+    parser.add_class_arguments(SourceA, "source_a")
+    parser.add_class_arguments(SourceB, "source_b")
+    parser.add_class_arguments(HierarchyRoot, "root")
+    parser.link_arguments(
+        "source_a",
+        "root.child.init_args.grandchild.init_args.param_grandchild",
+        apply_on="instantiate",
+        compute_fn=get_source_a_attr,
+    )
+    parser.link_arguments("source_b.attr_b", "root.child.init_args.param_child", apply_on="instantiate")
+    cfg = parser.parse_args([f"--config={json.dumps(config)}"])
+    init = parser.instantiate_classes(cfg)
+    assert isinstance(init.source_a, SourceA)
+    assert isinstance(init.source_b, SourceB)
+    assert isinstance(init.root, HierarchyRoot)
+    assert isinstance(init.root.child, HierarchyChild)
+    assert isinstance(init.root.child.grandchild, HierarchyGrandchild)
+    assert init.source_a.attr_a == "value a"
+    assert init.root.child.grandchild.attr_grandchild is init.source_a.attr_a
+    assert init.source_b.attr_b == "value b"
+    assert init.root.child.attr_child is init.source_b.attr_b
+
+
+class Dataloader:
+    def __init__(self, batch_size: int = 6):
+        self.batch_size = batch_size
+        self.num_classes = 7
+
+
+class CustomOptimizer(Optimizer):
+    def __init__(self, params: List[int], num_classes: int, **kwargs):
+        super().__init__(params, **kwargs)
+
+
+def custom_instantiator(class_type, *args, applied_instantiation_links: dict, **kwargs):
+    init = class_type(*args, **kwargs)
+    init.applied_instantiation_links = applied_instantiation_links
+    return init
+
+
+def test_on_instantiate_targets_passed_to_instantiator(parser):
+    parser.add_argument("--data", type=Dataloader)
+    parser.add_argument("--model", type=Model)
+    parser.link_arguments(
+        "data.num_classes",
+        "model.init_args.optimizer.init_args.num_classes",
+        apply_on="instantiate",
+    )
+    parser.add_instantiator(custom_instantiator, Dataloader, subclasses=True)
+    parser.add_instantiator(custom_instantiator, Model, subclasses=True)
+
+    cfg = parser.parse_args(["--data=Dataloader", "--model=Model", "--model.label=ok"])
+    init = parser.instantiate_classes(cfg)
+
+    assert isinstance(init.data, Dataloader)
+    assert init.data.applied_instantiation_links == {}
+    assert isinstance(init.model, Model)
+    assert callable(init.model.optimizer)
+    assert init.model.applied_instantiation_links == {"model.init_args.optimizer.init_args.num_classes": 7}
+
+
+@dataclass
+class DataDep:
+    param: int = 1
+
+
+@dataclass
+class DepContainer:
+    dep: DataDep
+    ref: str = ""
+
+
+def test_on_instantiate_target_entire_dataclass(parser, tmp_cwd):
+    parser.add_class_arguments(DataDep, "data")
+    parser.add_class_arguments(DepContainer, "container")
+    parser.link_arguments("data", "container.dep", apply_on="instantiate")
+
+    defaults = parser.get_defaults()
+    assert defaults == Namespace(data=Namespace(param=1), container=Namespace(ref=""))
+    cfg = parser.parse_args(["--data.param=2", "--container.ref=x"])
+    assert cfg == Namespace(data=Namespace(param=2), container=Namespace(ref="x"))
+    init = parser.instantiate_classes(cfg)
+    assert init.data is init.container.dep
+    assert init.container.dep.param == 2
+
+    help_str = get_parser_help(parser)
+    assert "data --> container.dep [applied on instantiate]" in help_str
+    assert "--container.dep" not in help_str
+
+
 # link creation failures
 
 
@@ -1000,9 +1169,9 @@ def test_on_instantiate_linking_deep_targets(parser, tmp_path):
         "c": {},
     }
     config_path = tmp_path / "config.yaml"
-    config_path.write_text(yaml.safe_dump(config))
+    config_path.write_text(json_or_yaml_dump(config))
 
-    parser.add_argument("--config", action=ActionConfigFile)
+    parser.add_argument("--config", action="config")
     parser.add_subclass_arguments(DeepBSuper, nested_key="b", required=True)
     parser.add_class_arguments(DeepC, nested_key="c")
     parser.link_arguments("c", "b.init_args.a.init_args.d", compute_fn=DeepC.fn, apply_on="instantiate")
@@ -1032,9 +1201,9 @@ def test_on_instantiate_linking_deep_targets_mapping(parser, tmp_path):
         "c": {},
     }
     config_path = tmp_path / "config.yaml"
-    config_path.write_text(yaml.safe_dump(config))
+    config_path.write_text(json_or_yaml_dump(config))
 
-    parser.add_argument("--config", action=ActionConfigFile)
+    parser.add_argument("--config", action="config")
     parser.add_subclass_arguments(DeepBSuper, nested_key="b", required=True)
     parser.add_class_arguments(DeepC, nested_key="c")
     parser.link_arguments(
@@ -1052,6 +1221,27 @@ def test_on_instantiate_linking_deep_targets_mapping(parser, tmp_path):
     assert isinstance(config_init["b"].a_map["name"].d, DeepD)
 
 
+def test_on_instantiate_linking_deep_targets_undefined_parent(parser, tmp_path):
+    config = {
+        "b": {
+            "class_path": f"{__name__}.DeepBSuper",
+        },
+        "c": {},
+    }
+    config_path = tmp_path / "config.yaml"
+    config_path.write_text(json_or_yaml_dump(config))
+
+    parser.add_argument("--config", action="config")
+    parser.add_subclass_arguments(DeepBSuper, nested_key="b", required=True)
+    parser.add_class_arguments(DeepC, nested_key="c")
+    # .init_args.a is undefined in DeepBSuper
+    parser.link_arguments("c", "b.init_args.a.init_args.d", compute_fn=DeepC.fn, apply_on="instantiate")
+
+    config = parser.parse_args([f"--config={config_path}"])
+    config_init = parser.instantiate_classes(config)
+    assert isinstance(config_init["b"], DeepBSuper)
+
+
 class DeepTarget:
     def __init__(self, a: int, b: int) -> None:
         self.a = a
